@@ -1,6 +1,6 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *
-* Copyright 2013 - 2024, nymea GmbH
+* Copyright 2013 - 2025, nymea GmbH
 * Contact: contact@nymea.io
 *
 * This file is part of nymea.
@@ -34,7 +34,8 @@
 #include "integrations/integrationplugin.h"
 #include "extern-plugininfo.h"
 
-#include "everestclient.h"
+#include "mqtt/everestmqttclient.h"
+#include "jsonrpc/everestconnection.h"
 
 #include <mqttclient.h>
 
@@ -58,9 +59,10 @@ public:
     void executeAction(ThingActionInfo *info) override;
 
 private:
-    QList<EverestClient *> m_everstClients;
-    QHash<Thing *, EverestClient *> m_thingClients;
+    QList<EverestMqttClient *> m_everstMqttClients;
+    QHash<Thing *, EverestMqttClient *> m_thingClients;
 
+    QHash<Thing *, EverestConnection *> m_everstConnections;
 };
 
 #endif // INTEGRATIONPLUGINEVEREST_H
